@@ -7,8 +7,6 @@ Module that contains constant definitions for tpDcc
 
 from __future__ import print_function, division, absolute_import
 
-from Qt.QtWidgets import QDialogButtonBox
-
 # =======~============ GENERAL
 PROJECTS_NAME = 'project.json'
 
@@ -103,13 +101,6 @@ class MaterialTypes(object):
     Standard = 0
 
 
-class DialogResult(object):
-    Yes = QDialogButtonBox.Yes
-    No = QDialogButtonBox.No
-    Cancel = QDialogButtonBox.Cancel
-    Close = QDialogButtonBox.Close
-
-
 SIDE_PATTERNS = {
     'center': ['C', 'c', 'Center', 'ct', 'center', 'middle', 'm'],
     'left': ['L', 'l', 'Left', 'left', 'lf'],
